@@ -15,8 +15,8 @@ describe 'glance::backend::s3' do
 
       it 'configures glance-api.conf' do
         is_expected.to contain_glance_api_config('glance_store/default_store').with_value('s3')
-        is_expected.to contain_glance_api_config('glance_store/s3_store_access_key').with_value('access').with_secret(true)
-        is_expected.to contain_glance_api_config('glance_store/s3_store_secret_key').with_value('secret').with_secret(true)
+        is_expected.to contain_glance_api_config('glance_store/s3_store_access_key').with_value('access')
+        is_expected.to contain_glance_api_config('glance_store/s3_store_secret_key').with_value('secret')
         is_expected.to contain_glance_api_config('glance_store/s3_store_host').with_value('host')
         is_expected.to contain_glance_api_config('glance_store/s3_store_bucket').with_value('bucket')
         is_expected.to contain_glance_api_config('glance_store/s3_store_bucket_url_format').with_value('<SERVICE DEFAULT>')
@@ -26,20 +26,6 @@ describe 'glance::backend::s3' do
         is_expected.to contain_glance_api_config('glance_store/s3_store_object_buffer_dir').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_glance_api_config('glance_store/s3_store_thread_pools').with_value('<SERVICE DEFAULT>')
       end
-      it 'not configures glance-glare.conf' do
-        is_expected.to_not contain_glance_glare_config('glance_store/default_store').with_value('s3')
-        is_expected.to_not contain_glance_glare_config('glance_store/s3_store_access_key').with_value('access')
-        is_expected.to_not contain_glance_glare_config('glance_store/s3_store_secret_key').with_value('secret')
-        is_expected.to_not contain_glance_glare_config('glance_store/s3_store_host').with_value('host')
-        is_expected.to_not contain_glance_glare_config('glance_store/s3_store_bucket').with_value('bucket')
-        is_expected.to_not contain_glance_glare_config('glance_store/s3_store_bucket_url_format').with_value('<SERVICE DEFAULT>')
-        is_expected.to_not contain_glance_glare_config('glance_store/s3_store_create_bucket_on_put').with_value('<SERVICE DEFAULT>')
-        is_expected.to_not contain_glance_glare_config('glance_store/s3_store_large_object_size').with_value('<SERVICE DEFAULT>')
-        is_expected.to_not contain_glance_glare_config('glance_store/s3_store_large_object_chunk_size').with_value('<SERVICE DEFAULT>')
-        is_expected.to_not contain_glance_glare_config('glance_store/s3_store_object_buffer_dir').with_value('<SERVICE DEFAULT>')
-        is_expected.to_not contain_glance_glare_config('glance_store/s3_store_thread_pools').with_value('<SERVICE DEFAULT>')
-      end
-
     end
 
     describe 'when overriding parameters' do
@@ -55,13 +41,12 @@ describe 'glance::backend::s3' do
           :large_object_chunk_size  => 20,
           :object_buffer_dir        => '/tmp',
           :thread_pools             => 20,
-          :glare_enabled            => true,
         }
       end
 
       it 'configures glance-api.conf' do
-        is_expected.to contain_glance_api_config('glance_store/s3_store_access_key').with_value('access2').with_secret(true)
-        is_expected.to contain_glance_api_config('glance_store/s3_store_secret_key').with_value('secret2').with_secret(true)
+        is_expected.to contain_glance_api_config('glance_store/s3_store_access_key').with_value('access2')
+        is_expected.to contain_glance_api_config('glance_store/s3_store_secret_key').with_value('secret2')
         is_expected.to contain_glance_api_config('glance_store/s3_store_host').with_value('host2')
         is_expected.to contain_glance_api_config('glance_store/s3_store_bucket').with_value('bucket2')
         is_expected.to contain_glance_api_config('glance_store/s3_store_bucket_url_format').with_value('path')
@@ -71,19 +56,6 @@ describe 'glance::backend::s3' do
         is_expected.to contain_glance_api_config('glance_store/s3_store_object_buffer_dir').with_value('/tmp')
         is_expected.to contain_glance_api_config('glance_store/s3_store_thread_pools').with_value('20')
       end
-
-      it 'configures glance-glare.conf' do
-        is_expected.to contain_glance_glare_config('glance_store/s3_store_access_key').with_value('access2')
-        is_expected.to contain_glance_glare_config('glance_store/s3_store_secret_key').with_value('secret2')
-        is_expected.to contain_glance_glare_config('glance_store/s3_store_host').with_value('host2')
-        is_expected.to contain_glance_glare_config('glance_store/s3_store_bucket').with_value('bucket2')
-        is_expected.to contain_glance_glare_config('glance_store/s3_store_bucket_url_format').with_value('path')
-        is_expected.to contain_glance_glare_config('glance_store/s3_store_create_bucket_on_put').with_value('true')
-        is_expected.to contain_glance_glare_config('glance_store/s3_store_large_object_size').with_value('200')
-        is_expected.to contain_glance_glare_config('glance_store/s3_store_large_object_chunk_size').with_value('20')
-        is_expected.to contain_glance_glare_config('glance_store/s3_store_object_buffer_dir').with_value('/tmp')
-        is_expected.to contain_glance_glare_config('glance_store/s3_store_thread_pools').with_value('20')
-      end
     end
 
     describe 'with invalid bucket_url_format' do
